nobs.vcmm_fit: Number of observations from a vcmm fit

View source: R/methods.R

nobs.vcmm_fitR Documentation

Number of observations from a vcmm fit

Description

Standard stats::nobs generic. Returns N, the total number of observations used to compute the fit (or the sum of node sample sizes for fits produced via fit_from_summaries).

Usage

## S3 method for class 'vcmm_fit'
nobs(object, ...)

Arguments

object

A vcmm_fit object.

...

Unused.

Value

Integer.


cevcmm documentation built on July 24, 2026, 5:07 p.m.