Generic in the style of nlme::fixef / lme4::fixef,
redefined here so cevcmm avoids a hard dependency on either.
If you also have nlme or lme4 loaded, call
cevcmm::fixef(fit) explicitly.
Value
The return value depends on the class of object; see
the appropriate method (e.g. fixef.vcmm_fit for
vcmm_fit objects, which returns a two-element list with
scalar intercept and a matrix varying of B-spline
basis coefficients).