Skip to contents

Standard stats::nobs generic. Returns \(N\), the total number of observations used to compute the fit (or the sum of node sample sizes for fits produced via fit_from_summaries).

Usage

# S3 method for class 'vcmm_fit'
nobs(object, ...)

Arguments

object

A vcmm_fit object.

...

Unused.

Value

Integer.